@@ -5,8 +5,8 @@ from hotsos.core.factory import FactoryBase
 from hotsos.core.log import log
 
 
-class FileObj(object):
-
+class FileObj():
+    """ Helper to enable querying filesystem entries. """
     def __init__(self, filename):
         self.filename = os.path.join(HotSOSConfig.data_root, filename)
 
