@@ -49,9 +49,13 @@ class KernelBase():
 class KernelChecks(KernelBase, plugintools.PluginPartBase):
     """ Base class for all kernel checks. """
     plugin_name = 'kernel'
-    plugin_root_index = 14
+    plugin_root_index = 1000
 
-    @property
-    def plugin_runnable(self):
-        # Always run
+    @classmethod
+    def is_runnable(cls):
+        """
+        Determine whether or not this plugin can and should be run.
+
+        @return: True or False
+        """
         return True
