@@ -7,14 +7,13 @@ from hotsos.core import host_helpers
 
 class KernelConfig(host_helpers.ConfigBase):
     """ Kernel configuration. """
-
     def __init__(self, *args, **kwargs):
         path = os.path.join(HotSOSConfig.data_root, "proc/cmdline")
         super().__init__(path=path, *args, **kwargs)
         self._cfg = {}
         self._load()
 
-    def get(self, key, expand_to_list=False):
+    def get(self, key, section=None, expand_to_list=False):
         value = self._cfg.get(key)
         if expand_to_list and value is not None:
             return self.expand_value_ranges(value)
@@ -30,7 +29,7 @@ class KernelConfig(host_helpers.ConfigBase):
         if not self.exists:
             return
 
-        with open(self.path) as fd:
+        with open(self.path, encoding='utf-8') as fd:
             for line in fd:
                 expr = r'.*\s+isolcpus=([0-9\-,]+)\s*.*'
                 ret = re.compile(expr).match(line)
@@ -39,9 +38,8 @@ class KernelConfig(host_helpers.ConfigBase):
                     break
 
 
-class SystemdConfig(host_helpers.SectionalConfigBase):
+class SystemdConfig(host_helpers.IniConfigBase):
     """Systemd configuration."""
-
     def __init__(self, *args, **kwargs):
         path = os.path.join(HotSOSConfig.data_root, "etc/systemd/system.conf")
         super().__init__(path=path, *args, **kwargs)
