@@ -1,10 +1,12 @@
 import os
+from dataclasses import dataclass, field
 from functools import cached_property
 
 from hotsos.core.config import HotSOSConfig
 from hotsos.core.host_helpers import (
     APTPackageHelper,
     HostNetworkingHelper,
+    InstallInfoBase,
     PebbleHelper,
     SnapPackageHelper,
     SystemdHelper,
@@ -30,7 +32,8 @@ K8S_PACKAGES = [r'cdk-addons',
                 r'kubelet',
                 r'kubeadm',
                 r'kubefed',
-                r'microk8s'
+                r'microk8s',
+                r'k8s',
                 ]
 # Packages that are used in a K8s deployment
 K8S_PACKAGE_DEPS = [r'charm[\S]+',
@@ -42,10 +45,29 @@ K8S_PACKAGE_DEPS = [r'charm[\S]+',
                     ]
 # Snap-only deps
 K8S_PACKAGE_DEPS_SNAP = [r'core[0-9]*']
+K8S_SNAP_DEPS = K8S_PACKAGE_DEPS + K8S_PACKAGE_DEPS_SNAP
+MICROK8S_COMMON = 'var/snap/microk8s/common'
+
+
+@dataclass
+class KubernetesInstallInfo(InstallInfoBase):
+    """ Kubernetes installation information. """
+    apt: APTPackageHelper = field(default_factory=lambda:
+                                  APTPackageHelper(
+                                                core_pkgs=K8S_PACKAGES,
+                                                other_pkgs=K8S_PACKAGE_DEPS))
+    pebble: PebbleHelper = field(default_factory=lambda:
+                                 PebbleHelper(service_exprs=SERVICES))
+    snaps: SnapPackageHelper = field(default_factory=lambda:
+                                     SnapPackageHelper(
+                                        core_snaps=K8S_PACKAGES,
+                                        other_snaps=K8S_SNAP_DEPS))
+    systemd: SystemdHelper = field(default_factory=lambda:
+                                   SystemdHelper(service_exprs=SERVICES))
 
 
 class KubernetesBase():
-    """ Base class for kuberenetes checks. """
+    """ Base class for Kubernetes checks. """
     @cached_property
     def flannel_ports(self):
         ports = []
@@ -68,9 +90,12 @@ class KubernetesBase():
         pods = []
         pods_path = os.path.join(HotSOSConfig.data_root,
                                  "var/log/pods")
-        if os.path.exists(pods_path):
-            for pod in os.listdir(pods_path):
-                pods.append(pod)
+        mk8s_pods_path = os.path.join(HotSOSConfig.data_root,
+                                      MICROK8S_COMMON, 'var/log/pods')
+        for path in [pods_path, mk8s_pods_path]:
+            if os.path.exists(path):
+                for pod in os.listdir(path):
+                    pods.append(pod)
 
         return sorted(pods)
 
@@ -79,10 +104,14 @@ class KubernetesBase():
         containers = []
         containers_path = os.path.join(HotSOSConfig.data_root,
                                        "var/log/containers")
-        if os.path.exists(containers_path):
-            for pod in os.listdir(containers_path):
-                pod = pod.partition('.log')[0]
-                containers.append(pod)
+        mk8s_containers_path = os.path.join(HotSOSConfig.data_root,
+                                            MICROK8S_COMMON,
+                                            'var/log/containers')
+        for path in [containers_path, mk8s_containers_path]:
+            if os.path.exists(path):
+                for ctr in os.listdir(path):
+                    ctr = ctr.partition('.log')[0]
+                    containers.append(ctr)
 
         return sorted(containers)
 
@@ -93,19 +122,18 @@ class KubernetesChecks(KubernetesBase, plugintools.PluginPartBase):
     plugin_root_index = 8
 
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        deps = K8S_PACKAGE_DEPS
-        # Deployments can use snap or apt versions of packages so we check both
-        self.apt = APTPackageHelper(core_pkgs=K8S_PACKAGES, other_pkgs=deps)
-        snap_deps = deps + K8S_PACKAGE_DEPS_SNAP
-        self.snaps = SnapPackageHelper(core_snaps=K8S_PACKAGES,
-                                       other_snaps=snap_deps)
-        self.pebble = PebbleHelper(service_exprs=SERVICES)
-        self.systemd = SystemdHelper(service_exprs=SERVICES)
+        super().__init__()
+        KubernetesInstallInfo().mixin(self)
 
-    @property
-    def plugin_runnable(self):
-        if self.apt.core or self.snaps.core:
+    @classmethod
+    def is_runnable(cls):
+        """
+        Determine whether or not this plugin can and should be run.
+
+        @return: True or False
+        """
+        k8s = KubernetesInstallInfo()
+        if k8s.apt.core or k8s.snaps.core:
             return True
 
         return False
