@@ -2,15 +2,19 @@ import abc
 from datetime import datetime
 import os
 import re
+from dataclasses import dataclass
 from functools import cached_property
 
 from hotsos.core.config import HotSOSConfig
-from hotsos.core.host_helpers.cli import CLIHelper, CmdBase
+from hotsos.core.host_helpers.cli import CLIHelper
+from hotsos.core.host_helpers.cli.common import CmdBase
 from hotsos.core.host_helpers import (
     APTPackageHelper,
     DockerImageHelper,
     DPKGVersion,
+    InstallInfoBase,
     PebbleHelper,
+    SnapPackageHelper,
     SystemdHelper,
     SSLCertificate,
     SSLCertificatesHelper,
@@ -20,6 +24,8 @@ from hotsos.core.plugins.openstack.openstack import (
     OSTProjectCatalog,
     OST_EOL_INFO,
     OST_REL_INFO,
+    OST_SUNBEAM_REL_INFO,
+    OST_SUNBEAM_SNAP_NAMES,
 )
 from hotsos.core.plugins.openstack.neutron import NeutronBase
 from hotsos.core.plugins.openstack.nova import NovaBase
@@ -28,39 +34,64 @@ from hotsos.core import plugintools
 from hotsos.core.ycheck.events import EventHandlerBase, EventCallbackBase
 
 
-class OpenstackBase():
+@dataclass
+class OSTProjectHelpers:
+    """ OpenStack project helper objects. """
+    nova: NovaBase
+    neutron: NeutronBase
+    octavia: OctaviaBase
+
+
+@dataclass
+class OpenStackInstallInfo(InstallInfoBase):
     """
-    Base class for Openstack checks.
+    OpenStack installation information.
+    """
+    project_catalog: OSTProjectCatalog = None
+
+    def __post_init__(self):
+        service_exprs = self.project_catalog.service_exprs
+        snap_core_pkgs = self.project_catalog.snap_core_exprs
+        core_pkgs = self.project_catalog.apt_core_exprs
+        other_pkgs = self.project_catalog.apt_dep_exprs
+
+        self.apt = APTPackageHelper(core_pkgs=core_pkgs,
+                                    other_pkgs=other_pkgs)
+        self.docker = DockerImageHelper(core_pkgs=core_pkgs,
+                                        other_pkgs=other_pkgs)
+        self.snaps = SnapPackageHelper(core_snaps=snap_core_pkgs)
+        self.pebble = PebbleHelper(service_exprs=service_exprs)
+        self.systemd = SystemdHelper(service_exprs=service_exprs)
+
+    def mixin(self, _self):
+        _self.apt = self.apt
+        _self.docker = self.docker
+        _self.pebble = self.pebble
+        _self.snaps = self.snaps
+        _self.systemd = self.systemd
+
+
+class OpenstackBase():  # pylint: disable=too-many-instance-attributes
+    """
+    Base class for OpenStack checks.
 
     Contains per-service information such as packages, versions, config etc.
     """
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.nova = NovaBase()
-        self.neutron = NeutronBase()
-        self.octavia = OctaviaBase()
         self.certificate_expire_days = 60
-        self.ost_projects = OSTProjectCatalog()
-        service_exprs = self.ost_projects.service_exprs
-        self.pebble = PebbleHelper(service_exprs=service_exprs)
-        self.systemd = SystemdHelper(service_exprs=service_exprs)
-        self.apt = APTPackageHelper(
-                       core_pkgs=self.ost_projects.packages_core_exprs,
-                       other_pkgs=self.ost_projects.packages_dep_exprs)
-        self.docker = DockerImageHelper(
-                          core_pkgs=self.ost_projects.packages_core_exprs,
-                          other_pkgs=self.ost_projects.packages_dep_exprs)
+        self.project_helpers = OSTProjectHelpers(NovaBase(), NeutronBase(),
+                                                 OctaviaBase())
+        self.project_catalog = OSTProjectCatalog()
+        # Keep pylint happy
+        self.apt = self.pebble = self.docker = self.snaps = self.systemd = None
+        OpenStackInstallInfo(project_catalog=self.project_catalog).mixin(self)
 
     @cached_property
     def apt_source_path(self):
         return os.path.join(HotSOSConfig.data_root, 'etc/apt/sources.list.d')
 
-    @cached_property
-    def installed_pkg_release_names(self):
-        """
-        Get release name for each installed package that we are tracking and
-        return as a list of names. The list should normally have length 1.
-        """
+    def _get_apt_relnames(self):
         relnames = set()
         for pkg, values in OST_REL_INFO.items():
             if pkg in self.apt.core:
@@ -81,6 +112,23 @@ class OpenstackBase():
                 if r_lt:
                     relnames.add(r_lt)
 
+        return relnames
+
+    @cached_property
+    def installed_pkg_release_names(self):
+        """
+        Get release name for each installed package that we are tracking and
+        return as a list of names. The list should normally have length 1.
+        """
+        if self.apt.core:
+            relnames = self._get_apt_relnames()
+        else:
+            relnames = set()
+            for pkg in OST_SUNBEAM_SNAP_NAMES:
+                if pkg in self.snaps.core:
+                    ver = self.snaps.get_version(pkg)
+                    relnames.add(OST_SUNBEAM_REL_INFO[ver])
+
         log.debug("release name(s) found: %s", ','.join(relnames))
         return list(relnames)
 
@@ -148,15 +196,15 @@ class OpenstackBase():
         """
         interfaces = {}
 
-        ifaces = self.nova.bind_interfaces
+        ifaces = self.project_helpers.nova.bind_interfaces
         if ifaces:
             interfaces.update(ifaces)
 
-        ifaces = self.neutron.bind_interfaces
+        ifaces = self.project_helpers.neutron.bind_interfaces
         if ifaces:
             interfaces.update(ifaces)
 
-        ifaces = self.octavia.bind_interfaces
+        ifaces = self.project_helpers.octavia.bind_interfaces
         if ifaces:
             interfaces.update(ifaces)
 
@@ -172,16 +220,9 @@ class OpenstackBase():
         if not masked:
             return []
 
-        expected_masked = self.ost_projects.default_masked_services
+        expected_masked = self.project_catalog.default_masked_services
         return sorted(list(masked.difference(expected_masked)))
 
-    @cached_property
-    def openstack_installed(self):
-        if self.apt.core:
-            return True
-
-        return False
-
     @cached_property
     def apache2_ssl_config_file(self):
         return os.path.join(HotSOSConfig.data_root,
@@ -248,9 +289,18 @@ class OpenStackChecks(plugintools.PluginPartBase):
     plugin_name = "openstack"
     plugin_root_index = 4
 
-    @cached_property
-    def plugin_runnable(self):
-        return OpenstackBase().openstack_installed
+    @classmethod
+    def is_runnable(cls):
+        """
+        Determine whether or not this plugin can and should be run.
+
+        @return: True or False
+        """
+        ost_common = OpenstackBase()
+        if ost_common.apt.core or ost_common.snaps.core:
+            return True
+
+        return False
 
 
 class OpenstackEventCallbackBase(OpenstackBase, EventCallbackBase):
