@@ -7,6 +7,7 @@ from hotsos.core.config import HotSOSConfig
 from hotsos.core import host_helpers
 from hotsos.core.log import log
 from hotsos.core.plugins.openstack.exceptions import (
+    OSLO_MESSAGING_EXCEPTIONS,
     EXCEPTIONS_COMMON,
 )
 from hotsos.core.plugins.openstack.exceptions_barbican import (
@@ -40,7 +41,6 @@ from hotsos.core.plugins.openstack.exceptions_masakari import (
 from hotsos.core.plugins.openstack.exceptions_neutron import (
     NEUTRON_EXCEPTIONS,
     NEUTRONCLIENT_EXCEPTIONS,
-    OVSDBAPP_EXCEPTIONS,
 )
 from hotsos.core.plugins.openstack.exceptions_nova import (
     NOVA_EXCEPTIONS,
@@ -48,6 +48,9 @@ from hotsos.core.plugins.openstack.exceptions_nova import (
     PLACEMENT_EXCEPTIONS,
     PYTHON_LIBVIRT_EXCEPTIONS,
 )
+from hotsos.core.plugins.openstack.exceptions_ovsdbapp import (
+    OVSDBAPP_EXCEPTIONS,
+)
 from hotsos.core.plugins.openstack.exceptions_octavia import (
     OCTAVIA_EXCEPTIONS,
 )
@@ -279,19 +282,36 @@ OST_REL_INFO = {
         'stein': '1.0.0'}
 }
 
-OST_EXCEPTIONS = {'barbican': BARBICAN_EXCEPTIONS + CASTELLAN_EXCEPTIONS,
-                  'cinder': CINDER_EXCEPTIONS + CASTELLAN_EXCEPTIONS,
-                  'designate': DESIGNATE_EXCEPTIONS,
+OST_SUNBEAM_SNAP_NAMES = ['openstack', 'openstack-hypervisor']
+
+OST_SUNBEAM_REL_INFO = {
+    '2025.1': 'epoxy',
+    '2024.2': 'dalmation',
+    '2024.1': 'caracal',
+    '2023.2': 'bobcat',
+    '2023.1': 'antelope',
+}
+
+OST_EXCEPTIONS = {'barbican': BARBICAN_EXCEPTIONS + CASTELLAN_EXCEPTIONS +
+                  OSLO_MESSAGING_EXCEPTIONS,
+                  'cinder': CINDER_EXCEPTIONS + CASTELLAN_EXCEPTIONS +
+                  OSLO_MESSAGING_EXCEPTIONS,
+                  'designate': DESIGNATE_EXCEPTIONS +
+                  OSLO_MESSAGING_EXCEPTIONS,
                   'glance': GLANCE_EXCEPTIONS + GLANCE_STORE_EXCEPTIONS,
-                  'heat': HEAT_EXCEPTIONS,
+                  'heat': HEAT_EXCEPTIONS +
+                  OSLO_MESSAGING_EXCEPTIONS,
                   'keystone': KEYSTONE_EXCEPTIONS,
-                  'manila': MANILA_EXCEPTIONS,
-                  'masakari': MASAKARI_EXCEPTIONS,
-                  'neutron': NEUTRON_EXCEPTIONS + OVSDBAPP_EXCEPTIONS,
+                  'manila': MANILA_EXCEPTIONS + OSLO_MESSAGING_EXCEPTIONS,
+                  'masakari': MASAKARI_EXCEPTIONS + OSLO_MESSAGING_EXCEPTIONS,
+                  'neutron': NEUTRON_EXCEPTIONS + OVSDBAPP_EXCEPTIONS +
+                  OSLO_MESSAGING_EXCEPTIONS,
                   'nova': NOVA_EXCEPTIONS + PYTHON_LIBVIRT_EXCEPTIONS +
-                  NEUTRONCLIENT_EXCEPTIONS + OS_VIF_EXCEPTIONS,
-                  'octavia': OCTAVIA_EXCEPTIONS,
-                  'placement': PLACEMENT_EXCEPTIONS,
+                  NEUTRONCLIENT_EXCEPTIONS + OS_VIF_EXCEPTIONS +
+                  OSLO_MESSAGING_EXCEPTIONS + OVSDBAPP_EXCEPTIONS,
+                  'octavia': OCTAVIA_EXCEPTIONS + OSLO_MESSAGING_EXCEPTIONS,
+                  'placement': PLACEMENT_EXCEPTIONS +
+                  OSLO_MESSAGING_EXCEPTIONS,
                   }
 
 
@@ -335,6 +355,21 @@ class OSTProjectParameters:
     log_path_overrides: dict = field(default_factory=lambda: {})
 
 
+@dataclass
+class OSTProjectAptHelperParams:
+    """ APTPackageHelper package matching expression lists. """
+    deps: list
+    core: list
+
+
+@dataclass
+class OSTProjectSystemdHelperParams:
+    """SystemdHelper service matching expression lists. """
+    extra_services: list
+    masked_services: list
+    deprecated_services: list
+
+
 class OSTProject():
     """
     Representation of an Openstack project/service.
@@ -367,28 +402,22 @@ class OSTProject():
                apache or if a package runs components using services whose name
                don't match the name of the project.
         """
+        self.params = params
         self.name = params.name
-        self.packages_deps = [self.PY_CLIENT_PREFIX.format(params.name)]
-        self.packages_core = [params.name]
+
+        self.apt_params = OSTProjectAptHelperParams([self.PY_CLIENT_PREFIX.
+                                                     format(params.name)],
+                                                    [params.name])
         if params.apt_core_alt:
-            self.packages_core.extend(params.apt_core_alt)
+            self.apt_params.core.extend(params.apt_core_alt)
             for c in params.apt_core_alt:
-                self.packages_deps.append(self.PY_CLIENT_PREFIX.format(c))
+                self.apt_params.deps.append(self.PY_CLIENT_PREFIX.format(c))
 
-        self.config = {}
-        if params.config:
-            for label, path in params.config.items():
-                path = os.path.join(
-                    HotSOSConfig.data_root,
-                    "etc",
-                    params.name,
-                    path
-                )
-                self.config[label] = OpenstackConfig(path)
+        self.systemd_params = OSTProjectSystemdHelperParams(
+                                params.systemd_extra_services,
+                                params.systemd_masked_services,
+                                params.systemd_deprecated_services)
 
-        self.systemd_extra_services = params.systemd_extra_services
-        self.systemd_masked_services = params.systemd_masked_services
-        self.systemd_deprecated_services = params.systemd_deprecated_services
         self.logs_path = os.path.join("var/log", params.name)
         self.log_path_overrides = params.log_path_overrides
         self.exceptions = EXCEPTIONS_COMMON + OST_EXCEPTIONS.get(
@@ -396,17 +425,34 @@ class OSTProject():
             []
         )
 
+    @cached_property
+    def config(self):
+        config = {}
+        if not self.params.config:
+            return config
+
+        for label, path in self.params.config.items():
+            path = os.path.join(
+                HotSOSConfig.data_root,
+                "etc",
+                self.params.name,
+                path
+            )
+            config[label] = OpenstackConfig(path)
+
+        return config
+
     @cached_property
     def installed(self):
         """ Return True if the openstack service is installed. """
         return bool(host_helpers.APTPackageHelper(
-                                            core_pkgs=self.packages_core).core)
+                        core_pkgs=self.apt_params.core).core)
 
     @cached_property
     def services_expr(self):
         exprs = [f'{self.name}{self.SVC_VALID_SUFFIX}']
-        if self.systemd_extra_services:
-            exprs += self.systemd_extra_services
+        if self.systemd_params.extra_services:
+            exprs += self.systemd_params.extra_services
         return exprs
 
     @cached_property
@@ -429,7 +475,7 @@ class OSTProject():
         yield proj_manage, [path]
         for svc in self.services:
             if (not include_deprecated_services and
-                    svc in self.systemd_deprecated_services):
+                    svc in self.systemd_params.deprecated_services):
                 continue
 
             path = os.path.join('var/log', self.name,
@@ -462,6 +508,9 @@ class OSTProjectCatalog():
                        'radvd',
                        ]
 
+    # ref: https://github.com/orgs/canonical/repositories?q=%22snap-open%22
+    SNAP_DEPS_SUNBEAM = [r'openstack\S*']
+
     def __init__(self):
         self._projects = {}
         self.add('aodh', config={'main': 'aodh.conf'},
@@ -578,7 +627,7 @@ class OSTProjectCatalog():
         """
         masked = []
         for p in self.all.values():
-            masked += p.systemd_masked_services
+            masked += p.systemd_params.masked_services
 
         return sorted(masked)
 
@@ -587,28 +636,37 @@ class OSTProjectCatalog():
         self._projects[name] = OSTProject(params)
 
     @cached_property
-    def packages_core_exprs(self):
+    def snap_core_exprs(self):
+        return self.SNAP_DEPS_SUNBEAM
+
+    @cached_property
+    def apt_core_exprs(self):
         core = set()
         for p in self.all.values():
-            core.update(p.packages_core)
+            core.update(p.apt_params.core)
 
         return list(core)
 
     @cached_property
-    def packages_dep_exprs(self):
+    def apt_dep_exprs(self):
         deps = set(self.APT_DEPS_COMMON)
         for p in self.all.values():
-            deps.update(p.packages_deps)
+            deps.update(p.apt_params.deps)
 
         return list(deps)
 
 
 class OSTServiceBase():
     """ Representation of an Openstack service. """
-    def __init__(self, name, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.nethelp = host_helpers.HostNetworkingHelper()
-        self.project = OSTProjectCatalog()[name]
+    PROJECT_NAME = None
+
+    @cached_property
+    def nethelp(self):
+        return host_helpers.HostNetworkingHelper()
+
+    @cached_property
+    def project(self):
+        return OSTProjectCatalog()[self.PROJECT_NAME]
 
     @cached_property
     def installed(self):
