@@ -17,34 +17,18 @@ from hotsos.core.search import (
     SearchDef,
     create_constraint,
 )
-from hotsos.core.plugins.openvswitch.common import OpenvSwitchGlobalSearchBase
+from hotsos.core.plugins.openvswitch.common import (
+    OpenvSwitchGlobalSearchBase,
+    OVSDBTableBase,
+)
 
 
-class OVSDBTable():
+class OVSDBTable(OVSDBTableBase):
     """
     Provides an interface to an OVSDB table. Records can be extracted from
     either 'get' or 'list' command outputs. We try 'get' first and of not found
     we search in output of 'list'.
     """
-    def __init__(self, name):
-        self.name = name
-
-    @staticmethod
-    def _convert_record_to_dict(record):
-        """ Convert the ovsdb record dict format to a python dictionary. """
-        out = {}
-        if not record or record == '{}':
-            return out
-
-        expr = r'(\S+="[^"]+"|\S+=\S+),? ?'
-        for field in re.compile(expr).findall(record):
-            for char in [',', '}', '{']:
-                field = field.strip(char)
-
-            key, _, val = field.partition('=')
-            out[key] = val.strip('"')
-
-        return out
 
     @staticmethod
     def _get_cmd(table):
@@ -56,33 +40,6 @@ class OVSDBTable():
         return lambda **kwargs: CLIHelper().ovs_vsctl_list(table=table,
                                                            **kwargs)
 
-    def _fallback_query(self, column):
-        """ Find first occurrence of column and return it. """
-        for cmd in [self._list_cmd(self.name),
-                    self._list_cmd(self.name.lower())]:
-            for line in cmd():
-                if not line.startswith(f'{column} '):
-                    continue
-
-                return line.partition(':')[2].strip()
-
-        return None
-
-    def get(self, record, column):
-        """
-        Try to get column using get command and failing that, try getting it
-        from list.
-        """
-        value = self._get_cmd(self.name)(record=record, column=column)
-        if not value:
-            value = self._fallback_query(column=column)
-
-        return self._convert_record_to_dict(value)
-
-    def __getattr__(self, column):
-        """ Get column for special records i.e. with key '.' """
-        return self.get(record='.', column=column)
-
 
 class OVSDB(FactoryBase):
     """
@@ -220,6 +177,41 @@ class OpenvSwitchBase():
         return False
 
 
+class OVSFDBStats(OpenvSwitchBase):
+    """ Interface to OVS Forwarding DataBase statistics. """
+    @cached_property
+    def bridges_with_fdb_overflow(self):
+        """
+        Check each bridge using 'ovs-appctl fdb/stats-show <br name>' to see if
+        its current MAC entries count is greater than the maximum allowed. If
+        current >= maximum, it means the FDB is full and we return a list of
+        affected bridges.
+
+        @return: list of bridges with full FDB.
+        """
+        expr = r'\s*Current/maximum MAC entries in the table: (\d+)/(\d+)'
+        searcher = FileSearcher()
+        with CLIHelperFile() as cli:
+            for bridge in self.bridges:
+                log.info("Checking FDB for bridge '%s'", bridge.name)
+                searcher.add(SearchDef(expr, tag=bridge.name),
+                             cli.ovs_appctl(command='fdb/stats-show',
+                                            args=bridge.name))
+
+            results = searcher.run().all
+            bridges = []
+            for r in results:
+                bridge = r.tag
+                current, maximum = int(r.get(1)), int(r.get(2))
+                log.debug("Bridge '%s', FDB size: current='%s' max='%s'",
+                          bridge, current, maximum)
+                # Testing for the FDB table full condition
+                if current >= maximum:
+                    bridges.append(bridge)
+
+        return bridges
+
+
 class OVSBFDSearch(OpenvSwitchGlobalSearchBase):
     """
     OVS BFD representation.
@@ -239,10 +231,14 @@ class OVSBFDSearch(OpenvSwitchGlobalSearchBase):
         """  # noqa
         pattern = (r'([\d-]+)T([\d:]+)\.\d+Z.+\|bfd\(\S+\)\|INFO\|'
                    r'([a-z0-9-]+): BFD state change: (\S+)')
+        constraints = []
         constraint = create_constraint(search_result_age_hours=24,
                                        min_hours_since_last_boot=0)
+        if constraint:
+            constraints.append(constraint)
+
         return SearchDef(pattern, tag=cls.unique_search_tag,
-                         constraints=[constraint])
+                         constraints=constraints)
 
     @classmethod
     def paths(cls):
