@@ -6,6 +6,6 @@ class StorageBase(plugintools.PluginPartBase):
     plugin_name = 'storage'
     plugin_root_index = 9
 
-    @property
-    def plugin_runnable(self):
+    @classmethod
+    def is_runnable(cls):
         raise NotImplementedError
