@@ -3,6 +3,7 @@ import re
 from functools import cached_property
 
 from hotsos.core.config import HotSOSConfig
+from hotsos.core.host_helpers.config import GenericIniConfig
 from hotsos.core.host_helpers import (
     CLIHelper, CLIHelperFile,
     SYSCtlFactory, UptimeHelper
@@ -14,7 +15,8 @@ from hotsos.core.search import (
 )
 
 
-class NUMAInfo(object):
+class NUMAInfo():
+    """ Interface to host NUMA information. """
     numactl = ""
 
     def __init__(self):
@@ -48,7 +50,7 @@ class NUMAInfo(object):
 
         for node in node_ids:
             for line in self.numactl:
-                expr = r'^node\s+{}\s+cpus:\s([0-9\s]+)'.format(node)
+                expr = rf'^node\s+{node}\s+cpus:\s([0-9\s]+)'
                 ret = re.compile(expr).match(line)
                 if ret:
                     self._nodes[node] = [int(e) for e in ret[1].split()]
@@ -74,8 +76,8 @@ class NUMAInfo(object):
         return self.nodes.get(node)
 
 
-class SystemBase(object):
-
+class SystemBase():
+    """ Base class for system checks. """
     @cached_property
     def date(self):
         return CLIHelper().date(no_format=True)
@@ -91,12 +93,16 @@ class SystemBase(object):
     @cached_property
     def os_release_name(self):
         data_source = os.path.join(HotSOSConfig.data_root, "etc/lsb-release")
-        if os.path.exists(data_source):
-            with open(data_source) as fd:
-                for line in fd.read().split():
-                    ret = re.compile(r"^DISTRIB_CODENAME=(.+)").match(line)
-                    if ret:
-                        return "ubuntu {}".format(ret[1])
+        if not os.path.exists(data_source):
+            return None
+
+        with open(data_source, encoding='utf-8') as fd:
+            for line in fd.read().split():
+                ret = re.compile(r"^DISTRIB_CODENAME=(.+)").match(line)
+                if ret:
+                    return f"ubuntu {ret[1]}"
+
+        return None
 
     @cached_property
     def virtualisation_type(self):
@@ -110,7 +116,7 @@ class SystemBase(object):
             if 'Virtualization' in split_line[0]:
                 return split_line[2].strip()
 
-        return
+        return None
 
     @cached_property
     def num_cpus(self):
@@ -128,7 +134,7 @@ class SystemBase(object):
     def unattended_upgrades_enabled(self):
         apt_config_dump = CLIHelper().apt_config_dump()
         if not apt_config_dump:
-            return
+            return None
 
         for line in apt_config_dump:
             ret = re.compile(r"^APT::Periodic::Unattended-Upgrade\s+"
@@ -136,6 +142,7 @@ class SystemBase(object):
             if ret:
                 if int(ret[1]) == 0:
                     return False
+
                 return True
 
         return False
@@ -224,3 +231,32 @@ class SystemBase(object):
     @cached_property
     def sysctl_all(self):
         return SYSCtlFactory().sysctl_all
+
+
+class SSSD():
+    """ SSSD interface. """
+    def __init__(self):
+        self.sssd_config = GenericIniConfig(
+            os.path.join(HotSOSConfig.data_root,
+                         "etc/sssd/sssd.conf"))
+
+    @property
+    def tokengroups_enabled_domains(self):
+        # If not explicitly closed
+        if not self.sssd_config:
+            return []
+
+        # Filter domain sections
+        domain_sections = [
+            x for x in self.sssd_config.all_sections if x.startswith("domain")
+        ]
+
+        ad_domain_sections = [
+            x for x in domain_sections
+            if self.sssd_config.get("id_provider", x) == "ad"]
+
+        ad_domain_sects_w_tokengroups = [
+            x for x in ad_domain_sections
+            if self.sssd_config.get("ldap_use_tokengroups", x) is not False]
+
+        return ad_domain_sects_w_tokengroups
