@@ -1,3 +1,4 @@
+import abc
 import os
 from enum import IntEnum, auto
 from dataclasses import dataclass
@@ -37,6 +38,10 @@ class PluginRegistryMeta(type):
         * class attribute 'summary_part_index' set to the integer index it
           should appear in the summary entry for that plugin. These indexes
           start at 0 and are unique to a plugin.
+
+    NOTE: at the time of writing these registrations are triggered by importing
+          the plugin in hotsos.plugin_extensions.__init__.py so be sure to add
+          new plugins there.
     """
 
     def __init__(cls, _name, _mro, members):
@@ -234,7 +239,12 @@ def summary_entry(name, index=0):
 
 
 def get_min_available_entry_index():
-    """ Return first index available after default entries. """
+    """ Return first available offset/index after default entries.
+
+    Default entries provided by ApplicationSummaryBase will use offsets from
+    DefaultSummaryEntryIndexes. This function is used to return the next
+    available offset for custom entry defintions.
+    """
     return DefaultSummaryEntryIndexes.AVAILABLE
 
 
@@ -353,7 +363,7 @@ class ApplicationSummaryBase(metaclass=PluginRegistryMeta):
         return None
 
 
-class PartManager():
+class PartOutputManager():
     """
     Collects output of all parts from a plugin and saves them in YAML format.
     """
@@ -477,13 +487,13 @@ class PluginPartBase(ApplicationSummaryBase):
 
         super().__init__(*args, **kwargs)
 
-    @property
-    def plugin_runnable(self):
+    @classmethod
+    @abc.abstractmethod
+    def is_runnable(cls):
         """
         Must be implemented by all plugins to define at runtime whether they
         should run.
         """
-        raise NotImplementedError
 
     @property
     def summary_subkey_include_default_entries(self):
@@ -597,8 +607,11 @@ class PluginRunner():
     defaults, providing a global searcher for the runtime of the plugin.
     """
     def __init__(self, plugin):
+        self.plugin = plugin
         self.parts = PLUGINS[plugin]
         self.failed_parts = []
+        self.part_mgr = PartOutputManager()
+        self.issues_mgr = IssuesManager()
 
     def _load_global_searcher(self, global_searcher):
         """ Load event and scenario searches into global searcher. """
@@ -623,11 +636,11 @@ class PluginRunner():
         @param global_searcher: GlobalSearcher object
         """
         always_run = {'auto_scenario_check': YScenarioChecker}
-        for name, always_parts in always_run.items():
+        for name, always_part in always_run.items():
             # update current env to reflect actual part being run
             HotSOSConfig.part_name = name
             try:
-                always_parts(global_searcher).run()
+                always_part(global_searcher).run()
             # We really do want to catch all here since we don't care why
             # it failed but don't want to fail hard if it does.
             except Exception as exc:  # pylint: disable=W0718
@@ -638,13 +651,40 @@ class PluginRunner():
             # for the summary so we wont check for it (they only raise
             # issues and bugs which are handled independently).
 
+    def _save_issues_to_summary(self):
+        """ Save any failures or bugs to the summary. """
+        if self.failed_parts:
+            # always put these at the top
+            self.part_mgr.save({'failed-parts': self.failed_parts}, index=0)
+
+        bugs = self.issues_mgr.load_bugs()
+        raised_issues = self.issues_mgr.load_issues()
+        summary_end_index = PluginPartBase.PLUGIN_PART_INDEX_MAX ** 2
+
+        # Add detected known_bugs and raised issues to end summary.
+        if bugs:
+            self.part_mgr.save(bugs, index=summary_end_index)
+
+        # Add raised issues to summary.
+        if raised_issues:
+            self.part_mgr.save(raised_issues, index=summary_end_index)
+
+    def _plugin_is_runnable(self):
+        """
+        Return True if any part of the current plugin is runnable.
+        """
+        for part_info in self.parts:
+            if part_info['runner'].is_runnable():
+                return True
+
+        return False
+
     def _run_plugin_parts(self, global_searcher):
         """ Execute parts for the current plugin context.
 
         @param global_searcher: GlobalSearcher object
         @return: dictionary summary of output.
         """
-        part_mgr = PartManager()
         for part_info in self.parts:
             # update current env to reflect actual part being run
             runner = part_info['runner']
@@ -656,59 +696,43 @@ class PluginRunner():
                 inst = runner(global_searcher=global_searcher)
 
             # Only run plugin if it declares itself runnable.
-            if not HotSOSConfig.force_mode and not inst.plugin_runnable:
-                log.debug("%s.%s.%s not runnable - skipping",
-                          HotSOSConfig.plugin_name, name, runner.__name__)
+            if not HotSOSConfig.force_mode and not inst.is_runnable():
+                log.debug("%s.%s not runnable - skipping",
+                          HotSOSConfig.plugin_name, name)
                 continue
 
-            log.debug("running %s.%s.%s",
-                      HotSOSConfig.plugin_name, name, runner.__name__)
+            log.debug("running %s.%s", HotSOSConfig.plugin_name, name)
             try:
                 # NOTE: since all parts are expected to be implementations
                 # of PluginPartBase we expect them to always define an
                 # output property.
-                output = inst.output
-                subkey = inst.summary_subkey
+                for key, entry in inst.output.items():
+                    out = {key: entry.data}
+                    if inst.summary_subkey:
+                        out = {inst.summary_subkey: out}
+
+                    part_max = PluginPartBase.PLUGIN_PART_INDEX_MAX
+                    part_index = part_info['summary_part_index']
+                    index = (part_index * part_max) + entry.index
+                    self.part_mgr.save(out, index=index)
             # We really do want to catch all here since we don't care why
             # it failed but don't want to fail hard if it does.
             except Exception as exc:  # pylint: disable=W0718
                 self.failed_parts.append(name)
                 log.exception("part '%s' raised exception: %s", name, exc)
-                output = None
 
-            if output:
-                for key, entry in output.items():
-                    out = {key: entry.data}
-                    if subkey:
-                        out = {subkey: out}
+        # Add issues to summary.
+        self._save_issues_to_summary()
 
-                    part_max = PluginPartBase.PLUGIN_PART_INDEX_MAX
-                    part_index = part_info['summary_part_index']
-                    index = (part_index * part_max) + entry.index
-                    part_mgr.save(out, index=index)
-
-        if self.failed_parts:
-            # always put these at the top
-            part_mgr.save({'failed-parts': self.failed_parts}, index=0)
-
-        imgr = IssuesManager()
-        bugs = imgr.load_bugs()
-        raised_issues = imgr.load_issues()
-        summary_end_index = PluginPartBase.PLUGIN_PART_INDEX_MAX ** 2
-
-        # Add detected known_bugs and raised issues to end summary.
-        if bugs:
-            part_mgr.save(bugs, index=summary_end_index)
-
-        # Add raised issues to summary.
-        if raised_issues:
-            part_mgr.save(raised_issues, index=summary_end_index)
-
-        return part_mgr.all()
+        return self.part_mgr.all()
 
     def run(self):
         """ Execute all plugin parts. """
         self.failed_parts = []
+        if not self._plugin_is_runnable():
+            log.info("plugin '%s' not runnable - skipping", self.plugin)
+            return {}
+
         with GlobalSearcher() as global_searcher:
             self._load_global_searcher(global_searcher)
 
