@@ -2,7 +2,7 @@ import os
 from datetime import timedelta
 from functools import cached_property
 
-from searchkit import (   # noqa: F403,F401, pylint: disable=W0611
+from searchkit import (
     FileSearcher as _FileSearcher,
     ResultFieldInfo,
     SearchDef,
@@ -17,6 +17,14 @@ from hotsos.core.host_helpers import CLIHelper, UptimeHelper
 from hotsos.core.log import log
 
 
+# This module acts as a proxy to searchkit but with some addons/modifications
+__all__ = [
+    ResultFieldInfo.__name__,
+    SearchDef.__name__,
+    SequenceSearchDef.__name__,
+    ]
+
+
 class FileSearcher(_FileSearcher):
     """
     Custom representation of searchkit FilesSearcher that sets some parameters
@@ -49,9 +57,9 @@ class SearchConstraintSearchSince(_SearchConstraintSearchSince):
 
         current_date = CLIHelper().date(format='+%Y-%m-%d %H:%M:%S')
         if not current_date or not isinstance(current_date, str):
-            log.error("current date '%s' being provided to search "
-                      "constraints is not valid.", current_date)
-            return
+            msg = (f"current date '{current_date}' being provided to search "
+                   "constraints is not valid.")
+            raise ValueError(msg)
 
         super().__init__(*args, current_date=current_date, **kwargs)
 
@@ -129,6 +137,9 @@ class CommonTimestampMatcher(TimestampMatcherBase):
         # should match plugins.openstack.openstack.OpenstackDateTimeMatcher
         openstack = (r'^(?P<year>\d{4})-(?P<month>\d{2})-(?P<day>\d{2})+\s+'
                      r'(?P<hours>\d{2}):(?P<minutes>\d{2}):(?P<seconds>\d+)')
+        apache = (r'^[\d.]+[\s-]+\[(?P<day>\d{2})/(?P<month>\w{3,5})/'
+                  r'(?P<year>\d{4}):(?P<hours>\d{2}):(?P<minutes>\d{2}):'
+                  r'(?P<seconds>\d+)\s+\+\d+\]')
         # since they are identical we wont add but leaving in case we want to.
         # edit later.
         # juju = openstack
@@ -140,7 +151,7 @@ class CommonTimestampMatcher(TimestampMatcherBase):
         # openvswitch = ceph
         kernlog = (r'^(?P<month>\w{3,5})\s+(?P<day>\d{1,2})\s+'
                    r'(?P<hours>\d{2}):(?P<minutes>\d{2}):(?P<seconds>\d{2})')
-        return [openstack, ceph, kernlog]
+        return [openstack, ceph, kernlog, apache]
 
 
 class ExtraSearchConstraints():
@@ -233,6 +244,11 @@ def create_constraint(search_result_age_hours=None,
         hours = min(hours,
                     max(uptime_etime_hours - min_hours_since_last_boot, 0))
 
-    return SearchConstraintSearchSince(
-                                     ts_matcher_cls=CommonTimestampMatcher,
-                                     hours=hours)
+        try:
+            return SearchConstraintSearchSince(
+                                        ts_matcher_cls=CommonTimestampMatcher,
+                                        hours=hours)
+        except ValueError as exc:
+            log.warning("failed to create search constraint: %s", exc)
+
+    return None
