@@ -9,9 +9,14 @@ from hotsos.core.ycheck.engine.properties.requires import (
 
 
 class YRequirementTypePath(YPropertyInputBase, YRequirementTypeBase):
-    """ Provides logic to perform checks on filesystem paths. """
-    _override_keys = ['path']
-    _overrride_autoregister = True
+    """
+    Path requires type property. Provides support for defining checks on a
+    filesystem path.
+
+    Provides logic to perform checks on filesystem paths.
+    """
+    override_keys = ['path']
+    override_autoregister = True
 
     @property
     def options(self):
