@@ -6,8 +6,11 @@ from hotsos.core.ycheck.engine.properties.requires import (
 
 
 class YPropertyVarOps(YRequirementTypeWithOpsBase):
-    _override_keys = ['varops']
-    _overrride_autoregister = True
+    """
+    Varops requires type property. Provides support for defining varops checks.
+    """
+    override_keys = ['varops']
+    override_autoregister = True
 
     @property
     def input(self):
