@@ -11,7 +11,6 @@ from hotsos.core.ycheck.engine import (
     YDefsSection,
 )
 from hotsos.core.ycheck.common import GlobalSearcherPreloaderBase
-from hotsos.core.ycheck.engine.properties import search
 from hotsos.core.exceptions import (
     NotEnoughParametersError,
     AlreadyLoadedError,
@@ -84,11 +83,35 @@ class EventProcessingUtils():
 
     @dataclass()
     class EventProcessingOptions:
-        """Common options for EventProcessingUtils functions."""
+        """Common options for EventProcessingUtils functions.
+
+        @param key_by_date: by default results are categorised by date but in
+                            situations where a small number of event types
+                            (keys) are spread across many dates/times it might
+                            make sense to categorise by event type.
+        @param include_time: If true events will be categorised by time beneath
+                             date to provide an extra level of granularity.
+        @param squash_if_none_keys: If true and any key is found to be None
+                                    (perhaps because a regex pattern did not
+                                    match properly) the results for each date
+                                    will be squashed to a number/count of
+                                    events.
+        @param max_results_per_date: an integer such that if key_by_date is
+                                     True this will pick the top N entries
+                                     with the highest count.
+        @param tally_value_limit_min: If provided, only tally values greater
+                                      than this will be included.
+        @param sort_tally_by_value: By default we sort tallied results by value
+                                    so that we prioritise keys with the highest
+                                    tally value. If we want to sort by key we
+                                    need to set this to False.
+        """
         key_by_date: bool = True
         include_time: bool = False
         squash_if_none_keys: bool = False
         max_results_per_date: int = None
+        tally_value_limit_min: int = None
+        sort_tally_by_value: bool = True
 
     @classmethod
     def _get_event_results(cls, event):
@@ -131,14 +154,23 @@ class EventProcessingUtils():
                      "fields",
                      _fail_count, event.name)
 
-    @staticmethod
-    def _get_tally(result, info, options: EventProcessingOptions):
+    @classmethod
+    def _get_tally_keys(cls, options, result):
+        """
+        By default we tally by 'key' unless options.key_by_date is True in
+        which case we tally by value i.e. the date.
+        """
         if options.key_by_date:
-            key = result['date']
-            value = result['key']
-        else:
-            key = result['key']
-            value = result['date']
+            return (result['date'], result['key'])
+
+        return (result['key'], result['date'])
+
+    @classmethod
+    def _get_tally(cls, result, info, options: EventProcessingOptions):
+        key, value = cls._get_tally_keys(options, result)
+        if (options.tally_value_limit_min is not None and
+                int(value) <= options.tally_value_limit_min):
+            return
 
         if key not in info:
             info[key] = {}
@@ -148,24 +180,35 @@ class EventProcessingUtils():
                 info[key] = 1
             else:
                 info[key] += 1
-        else:
-            ts_time = result.get('time')
-            if value not in info[key]:
-                if ts_time is not None and options.include_time:
-                    info[key][value] = {}
-                else:
-                    info[key][value] = 0
+            return
 
+        ts_time = result.get('time')
+        if value not in info[key]:
             if ts_time is not None and options.include_time:
-                if ts_time not in info[key][value]:
-                    info[key][value][ts_time] = 1
-                else:
-                    info[key][value][ts_time] += 1
+                info[key][value] = {}
             else:
-                info[key][value] += 1
+                info[key][value] = 0
 
-    @staticmethod
-    def _sort_results(categorised_results, options: EventProcessingOptions):
+        if ts_time is not None and options.include_time:
+            if ts_time not in info[key][value]:
+                info[key][value][ts_time] = 1
+            else:
+                info[key][value][ts_time] += 1
+        else:
+            info[key][value] += 1
+
+    @classmethod
+    def _sort_results(cls, categorised_results,
+                      options: EventProcessingOptions):
+        """
+        Sort results.
+
+        By default we sort result dates in ascending order then per-date
+        results in descending order of value (tally).
+
+        If results are categorised by value (not date) then we sort both in
+        descending order.
+        """
         log.debug("sorting categorised results")
         if all([options.key_by_date, options.include_time]):
             return {}
@@ -188,7 +231,10 @@ class EventProcessingUtils():
                     break
 
                 categorised_results[key] = sorted_dict(value,
-                                                       key=lambda e: e[1],
+                                                       key=lambda e:
+                                                           cls._get_sort_key(
+                                                                   e,
+                                                                   options),
                                                        reverse=True)
 
         return categorised_results
@@ -205,6 +251,19 @@ class EventProcessingUtils():
         """
         return False
 
+    @staticmethod
+    def _get_sort_key(item, options):
+        """
+        Determine whether to use dict item key or value as a sort key.
+
+        Field must be an integer or able to convert to int.
+
+        @param item: a 2-tuple of the form (key, value)
+        @param options: EventProcessingOptions
+        @return: integer key
+        """
+        return int(item[1]) if options.sort_tally_by_value else int(item[0])
+
     @classmethod
     def categorise_events(
         cls,
@@ -229,20 +288,8 @@ class EventProcessingUtils():
         @param event: EventCheckResult object
         @param results: optional list of results where each item is a dict with
                         keys 'date', 'key' and optionally 'time'.
-        @param key_by_date: by default results are categorised by date but in
-                            situations where a small number of event types
-                            (keys) are spread across many dates/times it might
-                            make sense to categorise by event type.
-        @param include_time: If true events will be categorised by time beneath
-                             date to provide an extra level of granularity.
-        @param squash_if_none_keys: If true and any key is found to be None
-                                    (perhaps because a regex pattern did not
-                                    match properly) the results for each date
-                                    will be squashed to a number/count of
-                                    events.
-        @param max_results_per_date: an integer such that if key_by_date is
-                                     True this will pick the top N entries
-                                     with the highest count.
+        @param options: optional EventProcessingOptions.
+        @return: dictionary of results
         """
         if options is None:
             options = EventProcessingUtils.EventProcessingOptions()
@@ -272,7 +319,7 @@ class EventProcessingUtils():
                 continue
 
             top_n = dict(sorted(entries.items(),
-                                key=lambda e: e[1],
+                                key=lambda e: cls._get_sort_key(e, options),
                                 reverse=True)[:options.max_results_per_date])
             shortened[date] = {
                 "total": len(entries),
@@ -301,61 +348,83 @@ class EventsSearchPreloader(YHandlerBase, GlobalSearcherPreloaderBase):
     object and execute the search before running any event callbacks.
     """
 
-    @staticmethod
-    def skip_filtered(path):
-        e_filter = HotSOSConfig.event_filter
-        if e_filter and path != e_filter:
-            log.info("skipping event %s (filter=%s)", path, e_filter)
-            return True
-
-        return False
-
-    def preload_searches(self, global_searcher, group=None):
+    def __init__(self, *args, group=None, **kwargs):
         """
-        Find all events that have a search property and load their search into
-        the global searcher.
-
-        @param global_searcher: GlobalSearcher object
         @param group: a group path can be provided to filter a subset of
                       items.
         """
-        if global_searcher.is_loaded(self.__class__.__name__):
+        super().__init__(*args, **kwargs)
+        self.event_group = group
+
+    @property
+    def filter(self):
+        return HotSOSConfig.event_filter
+
+    @cached_property
+    def root(self):
+        """ Return the root of all scenarios. """
+        plugin_defs = YDefsLoader('events',
+                                  filter_path=self.event_group).plugin_defs
+        return YDefsSection(HotSOSConfig.plugin_name, plugin_defs or {})
+
+    @property
+    def events(self):
+        """
+        Generator for all events.
+
+        Searches are expected to exist within checks so we extract them from
+        each event and discover their searches.
+
+        @return: event
+        """
+        for event in self.root.leaf_sections:
+            # NOTE: event is not an override object, it is a PTreeSection
+            # that contains the objects i.e. we go looking for the checks etc
+            # within this scenario (sub)section.
+            if self.skip_filtered(self.filter, event.resolve_path):
+                log.info("skipping event %s from pre-search "
+                         "(filter=%s)", event.resolve_path, self.filter)
+                continue
+
+            yield event
+
+    def _preload_searches(self):
+        """
+        Find all events that have a search property and load their search into
+        the global searcher.
+        """
+        if self.global_searcher.is_loaded(self.__class__.__name__):
             raise AlreadyLoadedError(
                 "event searches have already been loaded into the "
                 "global searcher. This operation can only be "
                 "performed once.")
 
-        log.debug("started loading (group=%s) searches into searcher "
-                  "(%s)", group, global_searcher.searcher)
+        log.debug("started loading event (group_filter=%s) searches into "
+                  "searcher (%s)", self.event_group,
+                  self.global_searcher.searcher)
 
-        plugin_defs = YDefsLoader('events', filter_path=group).plugin_defs
-        root = YDefsSection(HotSOSConfig.plugin_name, plugin_defs or {})
         added = 0
-        for prop in root.manager.properties.values():
-            if not issubclass(prop[0]['cls'], search.YPropertySearch):
+        for event in self.events:
+            if self.skip_filtered(self.filter, event.resolve_path):
+                log.info("skipping event %s from pre-search (filter=%s)",
+                         event.resolve_path, self.filter)
                 continue
 
-            for item in prop:
-                parent = self._find_search_prop_parent(root, item['path'])
-                if self.skip_filtered(parent.resolve_path):
-                    log.debug("skipping item %s", parent.resolve_path)
-                    continue
+            added += 1
+            self._load_item_search(self.global_searcher, event.search,
+                                   event.input)
 
-                added += 1
-                self._load_item_search(global_searcher, parent.search,
-                                       parent.input)
-
-        global_searcher.set_loaded(self.__class__.__name__)
+        self.global_searcher.set_loaded(self.__class__.__name__)
         log.debug("identified a total of %s event check searches", added)
         log.debug("finished loading event searches into searcher "
-                  "(registry now has %s items)", len(global_searcher))
+                  "(registry now has %s items)", len(self.global_searcher))
 
-    def run(self, group=None):
+    def run(self):
         log.debug("registered event callbacks:\n%s", '\n'.
                   join(CALLBACKS.keys()))
 
         # Pre-load all event searches into a global searcher
-        self.preload_searches(self.global_searcher, group=group)
+        self._preload_searches()
 
 
 class EventHandlerBase(YHandlerBase, EventProcessingUtils):
@@ -380,11 +449,15 @@ class EventHandlerBase(YHandlerBase, EventProcessingUtils):
                      self.event_group)
             # NOTE: this is not re-entrant safe and is only ever expected
             #       to be done from a unit test.
-            EventsSearchPreloader(self.global_searcher).run(
-                                                        group=self.event_group)
+            EventsSearchPreloader(self.global_searcher,
+                                  group=self.event_group).run()
 
         self._event_results = None
 
+    @property
+    def filter(self):
+        return HotSOSConfig.event_filter
+
     @staticmethod
     def meets_requirements(item):
         """
@@ -417,7 +490,10 @@ class EventHandlerBase(YHandlerBase, EventProcessingUtils):
 
         _events = {}
         for event in group.leaf_sections:
-            if EventsSearchPreloader.skip_filtered(event.resolve_path):
+            if EventsSearchPreloader.skip_filtered(self.filter,
+                                                   event.resolve_path):
+                log.info("skipping event %s (filter=%s)", event.resolve_path,
+                         HotSOSConfig.event_filter)
                 continue
 
             if not self.meets_requirements(event):
@@ -458,6 +534,28 @@ class EventHandlerBase(YHandlerBase, EventProcessingUtils):
 
         return {}
 
+    def _exec_callback(self, event, section_name, search_results,
+                       event_search):
+        # We want this to throw an exception if the callback is not
+        # defined.
+        callback_name = f'{self.event_group}.{event}'
+        if callback_name not in CALLBACKS:
+            msg = f"no callback found for event {callback_name}"
+            raise EventCallbackNotFound(msg)
+
+        callback = CALLBACKS[callback_name]
+        event_result = EventCheckResult(
+            name=event,
+            section_name=section_name,
+            results=search_results,
+            search_tag=event_search['search_tag'],
+            searcher=self.global_searcher.searcher,
+            sequence_def=event_search['sequence_search']
+        )
+        log.debug("executing event %s.%s callback '%s'",
+                  event_result.section_name, event, callback_name)
+        return callback()(event_result)
+
     def run(self):
         """
         Process each event and call respective callback functions when results
@@ -489,25 +587,8 @@ class EventHandlerBase(YHandlerBase, EventProcessingUtils):
                               event, event_search['search_tag'])
                     continue
 
-                # We want this to throw an exception if the callback is not
-                # defined.
-                callback_name = f'{self.event_group}.{event}'
-                if callback_name not in CALLBACKS:
-                    msg = f"no callback found for event {callback_name}"
-                    raise EventCallbackNotFound(msg)
-
-                callback = CALLBACKS[callback_name]
-                event_result = EventCheckResult(
-                    name=event,
-                    section_name=section_name,
-                    results=search_results,
-                    search_tag=search_tag,
-                    searcher=self.global_searcher.searcher,
-                    sequence_def=seq_def
-                )
-                log.debug("executing event %s.%s callback '%s'",
-                          event_result.section_name, event, callback_name)
-                ret = callback()(event_result)
+                ret = self._exec_callback(event, section_name, search_results,
+                                          event_search)
                 if not ret:
                     continue
 
