@@ -1,10 +1,12 @@
-# Must include cover all summary plugin handlers that need to be autoregister
+# Must include all summary plugin handlers that need to be autoregister
 from . import (  # noqa: F401
     juju,
     kernel,
     kubernetes,
+    landscape,
     lxd,
     maas,
+    microcloud,
     mysql,
     openstack,
     openvswitch,
