@@ -34,10 +34,9 @@ class ApacheEventCallback(OpenstackEventCallbackBase):
     event_group = 'apache'
     event_names = ['connection-refused']
 
-    def __call__(self, event):
-        ports_max = {}
+    @staticmethod
+    def _get_context_and_results(event):
         context = {}
-
         results = []
         for result in event.results:
             # save some context info
@@ -55,6 +54,13 @@ class ApacheEventCallback(OpenstackEventCallbackBase):
             results.append({'date': f"{year}-{month}-{day}",
                             'key': f"{addr}:{port}"})
 
+        return context, results
+
+    def __call__(self, event):
+        ports_max = {}
+
+        context, results = self._get_context_and_results(event)
+
         conns_refused = self.categorise_events(event, results=results)
         for addrs in conns_refused.values():
             for addr, count in addrs.items():
@@ -94,15 +100,23 @@ class ApacheEventChecks(OpenstackEventHandlerBase):
 
 
 class APIEventsCallback(OpenstackEventCallbackBase):
-    """ Implements Nova API events callback. """
+    """ Implements OpenStack REST API events callback. """
     event_group = 'http-requests'
-    event_names = ['neutron']
+    event_names = ['neutron', 'nova']
 
     def __call__(self, event):
         results = [{'date': r.get(1),
                     'key': r.get(2)} for r in event.results]
         ret = self.categorise_events(event, results=results)
         if ret:
+            if event.name == 'nova':
+                newdict = {}
+                for key, value in ret.items():
+                    d = datetime.datetime.strptime(key, '%d/%b/%Y')
+                    newdict[d.strftime("%Y-%m-%d")] = value
+
+                ret = newdict
+
             return ret
 
         return None
@@ -144,66 +158,65 @@ class AgentEventsCallback(OpenstackEventCallbackBase):
         return {"top": top5,
                 "stats": stats.get_event_stats()}
 
+    def _ovsdb_monitor_router_binding_transitions_event(self, event):
+        """
+        The ovsdbmonitor will print bindings which will eventually
+        reflect transitions so we need to filter out contiguous bindings
+        to the same chassis so that we are just left with transitions
+        that we can then count.
+
+        :param event: EventCheckResult
+        """
+        agent = event.section_name
+        results = []
+        for r in event.results:
+            results.append({'date': r.get(1), 'time': r.get(2),
+                            'router': r.get(3), 'key': r.get(4)})
+
+        results = sorted(results,
+                         key=lambda e:
+                         datetime.datetime.strptime(
+                             f"{e['date']} {e['time']}",
+                             '%Y-%m-%d %H:%M:%S'))
+
+        new_results = []
+        last_known = {}
+        host_key = 'key'
+        for item in results:
+            router = item['router']
+            if router not in last_known:
+                last_known[router] = item
+            elif last_known[router][host_key] != item[host_key]:
+                # remember hosts port transitioned from
+                new_results.append(last_known[router])
+                last_known[router] = item
+
+        ret = self.categorise_events(event, results=new_results)
+        if ret:
+            return {event.name: ret}, agent
+
+        return None
+
+    def _ml2_ovs_agent_events(self, event):
+        """
+        :param event: EventCheckResult
+        """
+        agent = event.section_name
+        ret = self._get_event_stats(event.results, event.search_tag)
+        if ret:
+            return {event.name: ret}, agent
+
+        return None
+
     def __call__(self, event):
         agent = event.section_name
         if event.name == 'ovsdb-monitor-router-binding-transitions':
-            # The ovsdbmonitor will print bindings which will eventually
-            # reflect transitions so we need to filter out contiguous bindings
-            # to the same chassis so that we are just left with transitions
-            # that we can then count.
-            results = []
-            for r in event.results:
-                results.append({'date': r.get(1), 'time': r.get(2),
-                                'router': r.get(3), 'key': r.get(4)})
+            return self._ovsdb_monitor_router_binding_transitions_event(event)
 
-            results = sorted(results,
-                             key=lambda e:
-                             datetime.datetime.strptime(
-                                 f"{e['date']} {e['time']}",
-                                 '%Y-%m-%d %H:%M:%S'))
+        if event.name in ['rpc-loop', 'router-spawn-events']:
+            return self._ml2_ovs_agent_events(event)
 
-            new_results = []
-            last_known = {}
-            host_key = 'key'
-            for item in results:
-                router = item['router']
-                if router not in last_known:
-                    last_known[router] = item
-                elif last_known[router][host_key] != item[host_key]:
-                    # remember hosts port transitioned from
-                    new_results.append(last_known[router])
-                    last_known[router] = item
-
-            ret = self.categorise_events(event, results=new_results)
-            if ret:
-                return {event.name: ret}, agent
-        elif event.name in self.ovsdbapp_event_names + \
-                self.ovn_mech_driver_events:
-            if event.name == 'ovn-resource-revision-bump':
-                ret = self.categorise_events(
-                    event,
-                    options=self.EventProcessingOptions(max_results_per_date=5)
-                )
-            elif event.name == 'ovsdb-transaction-aborted':
-                ret = {}
-                for result in event.results:
-                    _date = result.get(1)
-                    if _date in ret:
-                        ret[_date] += 1
-                    else:
-                        ret[_date] = 1
-
-                ret = sorted_dict(ret)
-            else:
-                ret = self.categorise_events(event)
-
-            if ret:
-                return {event.name: ret}, agent
-        elif event.name in ['rpc-loop', 'router-spawn-events']:
-            ret = self._get_event_stats(event.results, event.search_tag)
-            if ret:
-                return {event.name: ret}, agent
-        else:
+        if event.name in ['router-updates']:
             sri = SearchResultIndices(
                 event_id=4, metadata=3, metadata_key="router"
             )
@@ -212,6 +225,30 @@ class AgentEventsCallback(OpenstackEventCallbackBase):
             if ret:
                 return {event.name: ret}, agent
 
+            return None
+
+        # All other events should be covered by the following
+        if event.name == 'ovn-resource-revision-bump':
+            ret = self.categorise_events(
+                event,
+                options=self.EventProcessingOptions(max_results_per_date=5)
+            )
+        elif event.name == 'ovsdb-transaction-aborted':
+            ret = {}
+            for result in event.results:
+                _date = result.get(1)
+                if _date in ret:
+                    ret[_date] += 1
+                else:
+                    ret[_date] = 1
+
+            ret = sorted_dict(ret)
+        else:
+            ret = self.categorise_events(event)
+
+        if ret:
+            return {event.name: ret}, agent
+
         return None
 
 
@@ -292,15 +329,34 @@ class OctaviaAgentEventChecks(OpenstackEventHandlerBase):
         return None
 
 
-class PCINotFoundCallback(OpenstackEventCallbackBase):
-    """ Implements Nova PCINotFound error events callback. """
+class NovaComputeEventCallbacks(OpenstackEventCallbackBase):
+    """  Process nova-compute events. """
     event_group = 'nova.nova-compute'
-    event_names = ['pci-dev-not-found']
+    event_names = ['pci-dev-not-found', 'vm-build-times', 'lock-held-times']
 
     def __call__(self, event):
-        ret = self.categorise_events(event)
-        if ret:
-            return ret, 'PciDeviceNotFoundById'
+        if event.name == 'pci-dev-not-found':
+            ret = self.categorise_events(event)
+            if ret:
+                return ret, 'PciDeviceNotFoundById'
+        elif event.name == 'vm-build-times':
+            limit = 60
+            ret = self.categorise_events(event,
+                                         options=self.EventProcessingOptions(
+                                             tally_value_limit_min=limit,
+                                             sort_tally_by_value=False,
+                                             max_results_per_date=5))
+            if ret:
+                return {f'{event.name}-gt-{limit}s': ret}, 'nova-compute'
+        else:
+            # ignore times < 1s
+            ret = self.categorise_events(event,
+                                         options=self.EventProcessingOptions(
+                                             tally_value_limit_min=1,
+                                             sort_tally_by_value=False,
+                                             max_results_per_date=5))
+            if ret:
+                return {event.name: ret}, 'nova-compute'
 
         return None
 
