@@ -12,11 +12,11 @@ class OpenvSwitchSummary(OpenvSwitchChecks):
     """ Implementation of OpenvSwitch summary. """
     summary_part_index = 0
 
-    # REMINDER: common entries are implemented in the SummaryBase base class
-    #           and only application plugin specific customisations are
-    #           implemented here. We use the get_min_available_entry_index() to
-    #           ensure that additional entries don't clobber existing ones but
-    #           conversely can also replace them by re-using their indices.
+    # REMINDER: Common entries are implemented in
+    #           plugintools.ApplicationSummaryBase. Only customisations are
+    #           implemented here. See
+    #           plugintools.get_min_available_entry_index() for an explanation
+    #           on how entry indices are managed.
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -24,7 +24,7 @@ class OpenvSwitchSummary(OpenvSwitchChecks):
         self.ovn = OVNBase()
 
     @summary_entry('config', get_min_available_entry_index())
-    def summary_config(self):
+    def summary_ovsdb_config(self):
         _config = {}
         if self.ovs.offload_enabled:
             _config['offload'] = 'enabled'
@@ -37,6 +37,15 @@ class OpenvSwitchSummary(OpenvSwitchChecks):
         if _external_ids:
             _config['external-ids'] = _external_ids
 
+        db_keys = ['inactivity_probe', 'max_backoff']
+        for name, db in {'nbdb': self.ovn.nbdb, 'sbdb': self.ovn.sbdb}.items():
+            if db:
+                _config[name] = {}
+                for key in db_keys:
+                    val = getattr(db.Connection, key)
+                    if val:
+                        _config[name][key] = val
+
         return _config or None
 
     @summary_entry('bridges', get_min_available_entry_index() + 1)
@@ -75,7 +84,7 @@ class OpenvSwitchSummary(OpenvSwitchChecks):
         return self.ovs.tunnels or None
 
     @summary_entry('ovn', get_min_available_entry_index() + 3)
-    def summary_ovn(self):
+    def summary_ovn_resources(self):
         info = {}
         if self.ovn.nbdb:
             routers = self.ovn.nbdb.routers
